const newsFeed = document.getElementById("news-feed");
const newsFeedElPrimary = document.createElement("div");
const mainMastodonInstance = "https://mastodon.tedomum.net";
const mainAccountId = "73864";
const emergencyMastodonInstance = "https://piaille.fr";
const emergencyAccountId = "113511764126434175";

// Function to fetch data
const newsFetch = async (url) => {
	const response = await fetch(url, { mode: "cors" }).then(
		(res) => res.json(),
		(rej) => {
			console.error("⚠️", rej);
		},
	);
	return response;
};

// Function to fetch and append data
const getData = async (
	url,
	mastodonSVG,
	mastodonInstance,
	accountTitle,
	isEmergency = false,
) => {
	const capitalizeFirstLetter = (string) =>
		string.charAt(0).toUpperCase() + string.slice(1);

	try {
		const data = await newsFetch(url);
		const dateFormatOptions = {
			weekday: "long",
			year: "numeric",
			month: "long",
			day: "numeric",
			hour: "numeric",
			minute: "numeric",
			timeZone: "Europe/Paris",
		};

		if (data === undefined) throw new Error("No data…");

		const now = new Date();

		data
			.filter((el) => {
				// Filter non-sensitive posts and only posts from the past week for emergency account
				if (isEmergency) {
					const postDate = new Date(el.created_at);
					const oneWeekAgo = new Date();
					oneWeekAgo.setDate(now.getDate() - 7);
					return el.sensitive === false && postDate >= oneWeekAgo;
				}
				return el.sensitive === false;
			})
			.forEach((el) => {
				const dateCreated = new Date(el.created_at).toLocaleString(
					"fr-FR",
					dateFormatOptions,
				);
				const regexTag = new RegExp('(?<=rel="tag")', "g"); // Look for tag links
				const tootContent = (el.content || el.reblog.content).replaceAll(
					regexTag,
					' target="_blank"',
				); // Open tag links in new tab
				const tootURI = el.uri;

				// Add 'technical-account' class if 'isEmergency' is true
				const technicalClass = isEmergency ? " technical-account" : "";

				const technicalEmoji = isEmergency ? " 🛠️" : "";

				const postHTML = `<div class="mastodon-post${technicalClass}">
				  <div class="mastodon-post-content">
				    <div class="date-modified">
				      <a href="${tootURI}" target="_blank" title="Voir le pouet sur Mastodon">
				        ${capitalizeFirstLetter(dateCreated)}${technicalEmoji} 
				        <i class="fa fa-up-right-from-square" aria-hidden="true"></i>
				      </a>
				    </div>
				    ${tootContent}
				  </div>
				</div>`;

				if (isEmergency) {
					// Emergency posts always appear at the top
					newsFeedElPrimary.innerHTML = postHTML + newsFeedElPrimary.innerHTML;
				} else {
					// Regular posts are appended at the bottom
					newsFeedElPrimary.innerHTML += postHTML;
				}
			});
	} catch (e) {
		console.error("⚠️", e);
		newsFeedElPrimary.innerHTML += `<br><div class="alert alert-warning text-center">Impossible de récupérer les données de ${mastodonInstance}/@${accountTitle}…</div>`;
	}
};

// Mastodon SVG Icon
const mastodonSVG =
	'<svg xmlns="http://www.w3.org/2000/svg" height="1em" viewBox="0 0 448 512"><!--! Font Awesome Free 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --><path d="M433 179.11c0-97.2-63.71-125.7-63.71-125.7-62.52-28.7-228.56-28.4-290.48 0 0 0-63.72 28.5-63.72 125.7 0 115.7-6.6 259.4 105.63 289.1 40.51 10.7 75.32 13 103.33 11.4 50.81-2.8 79.32-18.1 79.32-18.1l-1.7-36.9s-36.31 11.4-77.12 10.1c-40.41-1.4-83-4.4-89.63-54a102.54 102.54 0 0 1-.9-13.9c85.63 20.9 158.65 9.1 178.75 6.7 56.12-6.7 105-41.3 111.23-72.9 9.8-49.8 9-121.5 9-121.5zm-75.12 125.2h-46.63v-114.2c0-49.7-64-51.6-64 6.9v62.5h-46.33V197c0-58.5-64-56.6-64-6.9v114.2H90.19c0-122.1-5.2-147.9 18.41-175 25.9-28.9 79.82-30.8 103.83 6.1l11.6 19.5 11.6-19.5c24.11-37.1 78.12-34.8 103.83-6.1 23.71 27.3 18.4 53 18.4 175z" fill="currentColor"></path></svg>';

// Apply consistent styling
newsFeed.classList.add("news-feed", "mb-3");
newsFeed.parentElement.classList.add("flex-article");
newsFeed.innerHTML = `<h2 class="h2 mt-4">Nos derniers pouets ! <a rel="me" href="https://mastodon.tedomum.net/@tedomum" target="_blank">${mastodonSVG}</a></h2>`;
newsFeedElPrimary.classList.add("news-feed-el");

// Fetch and append data for the emergency account first
getData(
	`${emergencyMastodonInstance}/api/v1/accounts/${emergencyAccountId}/statuses?limit=1&exclude_replies=true`,
	mastodonSVG,
	emergencyMastodonInstance,
	"tedomum_technique",
	true,
);

// Fetch and append data for the main account
getData(
	`${mainMastodonInstance}/api/v1/accounts/${mainAccountId}/statuses?limit=20&exclude_replies=true`,
	mastodonSVG,
	mainMastodonInstance,
	"tedomum",
	false,
);

// Append the combined feed to the newsFeed container
newsFeed.appendChild(newsFeedElPrimary);
